@@ -36,33 +36,21 @@
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <libxml/parser.h>
-#include <gtk/gtkcheckmenuitem.h>
 #include <gtk/gtkdnd.h>
 #include <gtk/gtkhbox.h>
-#include <gtk/gtkpaned.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtksignal.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-uidefs.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
-#include <libgnomevfs/gnome-vfs-types.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include <libnautilus-private/nautilus-dnd.h>
 #include <libnautilus-private/nautilus-directory.h>
 #include <libnautilus-private/nautilus-file-dnd.h>
-#include <libnautilus-private/nautilus-file-operations.h>
 #include <libnautilus-private/nautilus-file.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-keep-last-vertical-box.h>
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-mime-actions.h>
 #include <libnautilus-private/nautilus-program-choosing.h>
-#include <libnautilus-private/nautilus-trash-monitor.h>
 #include <libnautilus-private/nautilus-sidebar-provider.h>
 #include <libnautilus-private/nautilus-module.h>
-#include <math.h>
 
 struct NautilusInformationPanelDetails {
 	GtkVBox *container;
@@ -71,7 +59,6 @@ struct NautilusInformationPanelDetails {
 	GtkHBox *button_box_centerer;
 	GtkVBox *button_box;
 	gboolean has_buttons;
-	char *uri;
 	NautilusFile *file;
 	guint file_changed_connection;
 	gboolean background_connected;
@@ -87,7 +74,6 @@ struct NautilusInformationPanelDetails {
 
 static gboolean nautilus_information_panel_press_event           (GtkWidget                    *widget,
 								  GdkEventButton               *event);
-static void     nautilus_information_panel_destroy               (GtkObject                    *object);
 static void     nautilus_information_panel_finalize              (GObject                      *object);
 static void     nautilus_information_panel_drag_data_received    (GtkWidget                    *widget,
 								  GdkDragContext               *context,
@@ -100,7 +86,6 @@ static void     nautilus_information_panel_read_defaults         (NautilusInform
 static void     nautilus_information_panel_style_set             (GtkWidget                    *widget,
 								  GtkStyle                     *previous_style);
 static void     nautilus_information_panel_theme_changed         (gpointer                      user_data);
-static void     nautilus_information_panel_confirm_trash_changed (gpointer                      user_data);
 static void     nautilus_information_panel_update_appearance     (NautilusInformationPanel     *information_panel);
 static void     nautilus_information_panel_update_buttons        (NautilusInformationPanel     *information_panel);
 static void     add_command_buttons                              (NautilusInformationPanel     *information_panel,
@@ -111,8 +96,6 @@ static void     nautilus_information_panel_iface_init            (NautilusSideba
 static void     sidebar_provider_iface_init                      (NautilusSidebarProviderIface *iface);
 static GType    nautilus_information_panel_provider_get_type     (void);
 
-static gboolean confirm_trash_auto_value = TRUE;
-
 enum {
 	LOCATION_CHANGED,
 	LAST_SIGNAL
@@ -213,16 +196,12 @@ nautilus_information_panel_class_init (NautilusInformationPanelClass *klass)
 {
 	GtkWidgetClass *widget_class;
 	GObjectClass *gobject_class;
-	GtkObjectClass *object_class;
 	
 	gobject_class = G_OBJECT_CLASS (klass);
-	object_class = GTK_OBJECT_CLASS (klass);
 	widget_class = GTK_WIDGET_CLASS (klass);
 	
 	gobject_class->finalize = nautilus_information_panel_finalize;
 
-	object_class->destroy = nautilus_information_panel_destroy;
-	
 	widget_class->drag_data_received  = nautilus_information_panel_drag_data_received;
 	widget_class->button_press_event  = nautilus_information_panel_press_event;
 	widget_class->style_set = nautilus_information_panel_style_set;
@@ -262,18 +241,10 @@ static void
 nautilus_information_panel_init (NautilusInformationPanel *information_panel)
 {
 	GtkWidget *widget;
-	static gboolean setup_autos = FALSE;
 
 	widget = GTK_WIDGET (information_panel);
 
 	information_panel->details = g_new0 (NautilusInformationPanelDetails, 1);
-
-	if (!setup_autos) {
-		setup_autos = TRUE;
-		eel_preferences_add_auto_boolean (
-			NAUTILUS_PREFERENCES_CONFIRM_TRASH,
-			&confirm_trash_auto_value);
-	}	
 	
 	/* load the default background */
 	nautilus_information_panel_read_defaults (information_panel);
@@ -303,9 +274,6 @@ nautilus_information_panel_init (NautilusInformationPanel *information_panel)
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_SIDE_PANE_BACKGROUND_COLOR, nautilus_information_panel_theme_changed, information_panel);
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_SIDE_PANE_BACKGROUND_FILENAME, nautilus_information_panel_theme_changed, information_panel);
 
-	/* add a callback for when the preference whether to confirm trashing/deleting file changes */
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_CONFIRM_TRASH, nautilus_information_panel_confirm_trash_changed, information_panel);
-
 	/* prepare ourselves to receive dropped objects */
 	gtk_drag_dest_set (GTK_WIDGET (information_panel),
 			   GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP, 
@@ -313,16 +281,6 @@ nautilus_information_panel_init (NautilusInformationPanel *information_panel)
 			   GDK_ACTION_COPY | GDK_ACTION_MOVE | GDK_ACTION_ASK);
 }
 
-static void
-nautilus_information_panel_destroy (GtkObject *object)
-{
-	NautilusInformationPanel *information_panel;
-
-	information_panel = NAUTILUS_INFORMATION_PANEL (object);
-
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
-}
-
 static void
 nautilus_information_panel_finalize (GObject *object)
 {
@@ -335,7 +293,6 @@ nautilus_information_panel_finalize (GObject *object)
 		nautilus_file_unref (information_panel->details->file);
 	}
 	
-	g_free (information_panel->details->uri);
 	g_free (information_panel->details->default_background_color);
 	g_free (information_panel->details->default_background_image);
 	g_free (information_panel->details->current_background_color);
@@ -352,11 +309,6 @@ nautilus_information_panel_finalize (GObject *object)
 					 nautilus_information_panel_theme_changed,
 					 information_panel);
 
-	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_CONFIRM_TRASH,
-					 nautilus_information_panel_confirm_trash_changed,
-					 information_panel);
-
-
 	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
@@ -459,17 +411,6 @@ nautilus_information_panel_theme_changed (gpointer user_data)
 	gtk_widget_queue_draw (GTK_WIDGET (information_panel)) ;	
 }
 
-/* handler for handling confirming trash preferences changes */
-
-static void
-nautilus_information_panel_confirm_trash_changed (gpointer user_data)
-{
-	NautilusInformationPanel *information_panel;
-	
-	information_panel = NAUTILUS_INFORMATION_PANEL (user_data);
-	nautilus_information_panel_update_buttons (information_panel);
-}
-
 /* hit testing */
 
 static InformationPanelPart
@@ -494,7 +435,7 @@ uri_is_local_image (const char *uri)
 	GdkPixbuf *pixbuf;
 	char *image_path;
 	
-	image_path = gnome_vfs_get_local_path_from_uri (uri);
+	image_path = g_filename_from_uri (uri, NULL, NULL);
 	if (image_path == NULL) {
 		return FALSE;
 	}
@@ -518,8 +459,8 @@ receive_dropped_uri_list (NautilusInformationPanel *information_panel,
 	char **uris;
 	gboolean exactly_one;
 	GtkWindow *window;
-	
-	uris = g_strsplit (selection_data->data, "\r\n", 0);
+
+	uris = g_uri_list_extract_uris ((gchar *) selection_data->data);
 	exactly_one = uris[0] != NULL && (uris[1] == NULL || uris[1][0] == '\0');
 	window = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (information_panel)));
 	
@@ -569,7 +510,10 @@ receive_dropped_uri_list (NautilusInformationPanel *information_panel,
 							    NULL);
 			}
 		} else {	
-			if (eel_is_remote_uri (uris[0])) {
+			GFile *f;
+
+			f = g_file_new_for_uri (uris[0]);
+			if (!g_file_is_native (f)) {
 				eel_show_error_dialog (
 					_("The file that you dropped is not local."),
 					_("You can only use local images as custom icons."), 
@@ -581,6 +525,7 @@ receive_dropped_uri_list (NautilusInformationPanel *information_panel,
 					_("You can only use images as custom icons."),
 					window);
 			}
+			g_object_unref (f);
 		}	
 		break;
 	}
@@ -595,7 +540,7 @@ receive_dropped_color (NautilusInformationPanel *information_panel,
 		       GtkSelectionData *selection_data)
 {
 	guint16 *channels;
-	char *color_spec;
+	char color_spec[8];
 
 	if (selection_data->length != 8 || selection_data->format != 16) {
 		g_warning ("received invalid color data");
@@ -603,7 +548,8 @@ receive_dropped_color (NautilusInformationPanel *information_panel,
 	}
 	
 	channels = (guint16 *) selection_data->data;
-	color_spec = g_strdup_printf ("#%02X%02X%02X", channels[0] >> 8, channels[1] >> 8, channels[2] >> 8);
+	g_snprintf (color_spec, sizeof (color_spec),
+		    "#%02X%02X%02X", channels[0] >> 8, channels[1] >> 8, channels[2] >> 8);
 
 	switch (hit_test (information_panel, x, y)) {
 	case NO_PART:
@@ -625,7 +571,6 @@ receive_dropped_color (NautilusInformationPanel *information_panel,
 		
 		break;
 	}
-	g_free(color_spec);
 }
 
 /* handle receiving a dropped keyword */
@@ -848,25 +793,18 @@ nautilus_information_panel_get_window (NautilusInformationPanel *information_pan
 }
 
 static void
-command_button_callback (GtkWidget *button, char *id_str)
+command_button_callback (GtkWidget *button, GAppInfo *application)
 {
 	NautilusInformationPanel *information_panel;
-	GnomeVFSMimeApplication *application;
 	GList files;
 	
 	information_panel = NAUTILUS_INFORMATION_PANEL (g_object_get_data (G_OBJECT (button), "user_data"));
 
-	application = gnome_vfs_mime_application_new_from_desktop_id (id_str);
-
-	if (application != NULL) {
-		files.next = NULL;
-		files.prev = NULL;
-		files.data = information_panel->details->file;
-		nautilus_launch_application (application, &files,
-					     nautilus_information_panel_get_window (information_panel));	
-
-		gnome_vfs_mime_application_free (application);
-	}
+	files.next = NULL;
+	files.prev = NULL;
+	files.data = information_panel->details->file;
+	nautilus_launch_application (application, &files,
+				     nautilus_information_panel_get_window (information_panel));	
 }
 
 /* interpret commands for buttons specified by metadata. Handle some built-in ones explicitly, or fork
@@ -885,10 +823,10 @@ metadata_button_callback (GtkWidget *button, const char *command_str)
 static void
 add_command_buttons (NautilusInformationPanel *information_panel, GList *application_list)
 {
-	char *id_string, *temp_str;
+	char *temp_str;
 	GList *p;
 	GtkWidget *temp_button, *label;
-	GnomeVFSMimeApplication *application;
+	GAppInfo *application;
 
 	/* There's always at least the "Open with..." button */
 	information_panel->details->has_buttons = TRUE;
@@ -896,7 +834,7 @@ add_command_buttons (NautilusInformationPanel *information_panel, GList *applica
 	for (p = application_list; p != NULL; p = p->next) {
 	        application = p->data;	        
 
-		temp_str = g_strdup_printf (_("Open with %s"), application->name);
+		temp_str = g_strdup_printf (_("Open with %s"), g_app_info_get_name (application));
 	        temp_button = gtk_button_new_with_label (temp_str);
 		label = GTK_BIN (temp_button)->child;
 		gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_START);
@@ -906,11 +844,12 @@ add_command_buttons (NautilusInformationPanel *information_panel, GList *applica
 				    FALSE, FALSE, 
 				    0);
 
-		id_string = g_strdup (gnome_vfs_mime_application_get_desktop_id (application));
-
-		eel_gtk_signal_connect_free_data 
-			(GTK_OBJECT (temp_button), "clicked",
-			 G_CALLBACK (command_button_callback), id_string);
+		g_signal_connect_data (temp_button,
+				       "clicked",
+				       G_CALLBACK (command_button_callback),
+				       g_object_ref (application),
+				       (GClosureNotify)g_object_unref,
+				       0);
 
                 g_object_set_data (G_OBJECT (temp_button), "user_data", information_panel);
 		
@@ -952,10 +891,14 @@ add_buttons_from_metadata (NautilusInformationPanel *information_panel, const ch
 					information_panel->details->has_buttons = TRUE;
 					command_string = g_strdup (temp_str + 1);
 					g_free (button_name);
-					
-					eel_gtk_signal_connect_free_data 
-						(GTK_OBJECT (temp_button), "clicked",
-						 G_CALLBACK (metadata_button_callback), command_string);
+
+					g_signal_connect_data (temp_button,
+							       "clicked",
+							       G_CALLBACK (metadata_button_callback),
+							       command_string,
+							       (GClosureNotify)g_free,
+							       0);
+
 		                	g_object_set_data (G_OBJECT (temp_button), "user_data", information_panel);
 					
 					gtk_widget_show (temp_button);			
@@ -967,43 +910,6 @@ add_buttons_from_metadata (NautilusInformationPanel *information_panel, const ch
 	g_strfreev (terms);
 }
 
-/* handle the hacked-in empty trash command */
-static void
-empty_trash_callback (GtkWidget *button, gpointer data)
-{
-	GtkWidget *window;
-	
-	window = gtk_widget_get_toplevel (button);
-	nautilus_file_operations_empty_trash (window);
-}
-
-
-static void
-burn_cd_callback (GtkWidget *button, gpointer data)
-{
-	GError *error;
-	char *argv[] = { "nautilus-cd-burner", NULL};
-
-	error = NULL;
-	if (!g_spawn_async (NULL,
-			    argv, NULL,
-			    G_SPAWN_SEARCH_PATH,
-			    NULL, NULL,
-			    NULL,
-			    &error)) {
-		eel_show_error_dialog (_("Unable to launch the cd burner application."), error->message,
-				       GTK_WINDOW (gtk_widget_get_toplevel (button)));
-		g_error_free (error);
-	}
-}
-
-static void
-nautilus_information_panel_trash_state_changed_callback (NautilusTrashMonitor *trash_monitor,
-						gboolean state, gpointer callback_data)
-{
-		gtk_widget_set_sensitive (GTK_WIDGET (callback_data), !nautilus_trash_monitor_is_empty ());
-}
-
 /*
  * nautilus_information_panel_update_buttons:
  * 
@@ -1013,7 +919,6 @@ static void
 nautilus_information_panel_update_buttons (NautilusInformationPanel *information_panel)
 {
 	char *button_data;
-	GtkWidget *temp_button;
 	GList *short_application_list;
 	
 	/* dispose of any existing buttons */
@@ -1032,43 +937,12 @@ nautilus_information_panel_update_buttons (NautilusInformationPanel *information
 		g_free(button_data);
 	}
 
-	/* here is a hack to provide an "empty trash" button when displaying the trash.  Eventually, we
-	 * need a framework to allow protocols to add commands buttons */
-	if (eel_istr_has_prefix (information_panel->details->uri, "trash:")) {
-		/* FIXME: We don't use spaces to pad labels! */
-		temp_button = gtk_button_new_with_mnemonic (_("Empty _Trash"));
-
-		gtk_box_pack_start (GTK_BOX (information_panel->details->button_box), 
-					temp_button, FALSE, FALSE, 0);
-		gtk_widget_set_sensitive (temp_button, !nautilus_trash_monitor_is_empty ());
-		gtk_widget_show (temp_button);
-		information_panel->details->has_buttons = TRUE;
-					
-		g_signal_connect (temp_button, "clicked",
-				  G_CALLBACK (empty_trash_callback), NULL);
-		
-		g_signal_connect_object (nautilus_trash_monitor_get (), "trash_state_changed",
-					 G_CALLBACK (nautilus_information_panel_trash_state_changed_callback), temp_button, 0);
-	}
-	if (eel_istr_has_prefix (information_panel->details->uri, "burn:")) {
-		/* FIXME: We don't use spaces to pad labels! */
-		temp_button = gtk_button_new_with_mnemonic (_("_Write contents to CD"));
-
-		gtk_box_pack_start (GTK_BOX (information_panel->details->button_box), 
-					temp_button, FALSE, FALSE, 0);
-		gtk_widget_show (temp_button);
-		information_panel->details->has_buttons = TRUE;
-					
-		g_signal_connect (temp_button, "clicked",
-				  G_CALLBACK (burn_cd_callback), NULL);
-	}
-
 	/* Make buttons for each application */
 	if (nautilus_mime_has_any_applications_for_file (information_panel->details->file)) {
 		short_application_list = 
 			nautilus_mime_get_applications_for_file (information_panel->details->file);
 		add_command_buttons (information_panel, short_application_list);
-		gnome_vfs_mime_application_list_free (short_application_list);
+		eel_g_object_list_free (short_application_list);
 	}
 
 	gtk_widget_show (GTK_WIDGET (information_panel->details->button_box_centerer));
@@ -1135,14 +1009,13 @@ nautilus_information_panel_update_appearance (NautilusInformationPanel *informat
 					   information_panel);
 }
 
-
 static void
 background_metadata_changed_callback (NautilusInformationPanel *information_panel)
 {
 	NautilusFileAttributes attributes;
 	gboolean ready;
 
-	attributes = nautilus_mime_actions_get_minimum_file_attributes ();
+	attributes = nautilus_mime_actions_get_required_file_attributes ();
 	ready = nautilus_file_check_if_ready (information_panel->details->file, attributes);
 
 	if (ready) {
@@ -1168,24 +1041,20 @@ nautilus_information_panel_set_uri (NautilusInformationPanel *information_panel,
 	g_return_if_fail (initial_title != NULL);
 
 	/* there's nothing to do if the uri is the same as the current one */ 
-	if (eel_strcmp (information_panel->details->uri, new_uri) == 0) {
+	if (information_panel->details->file != NULL &&
+	    nautilus_file_matches_uri (information_panel->details->file, new_uri)) {
 		return;
 	}
-	
-	g_free (information_panel->details->uri);
-	information_panel->details->uri = g_strdup (new_uri);
-		
+
 	if (information_panel->details->file != NULL) {
 		g_signal_handler_disconnect (information_panel->details->file, 
 					     information_panel->details->file_changed_connection);
 		nautilus_file_monitor_remove (information_panel->details->file, information_panel);
 	}
 
-
-	file = nautilus_file_get (information_panel->details->uri);
+	file = nautilus_file_get_by_uri (new_uri);
 
 	nautilus_file_unref (information_panel->details->file);
-
 	information_panel->details->file = file;
 	
 	information_panel->details->file_changed_connection =
@@ -1193,7 +1062,7 @@ nautilus_information_panel_set_uri (NautilusInformationPanel *information_panel,
 					 G_CALLBACK (background_metadata_changed_callback),
 					 information_panel, G_CONNECT_SWAPPED);
 
-	attributes = nautilus_mime_actions_get_minimum_file_attributes ();
+	attributes = nautilus_mime_actions_get_required_file_attributes ();
 	nautilus_file_monitor_add (information_panel->details->file, information_panel, attributes);
 
 	background_metadata_changed_callback (information_panel);
@@ -1258,8 +1127,6 @@ nautilus_information_panel_set_parent_window (NautilusInformationPanel *panel,
 					    title);
 	g_free (location);
 	g_free (title);
-
-
 }
 
 static NautilusSidebar *
@@ -1292,7 +1159,6 @@ nautilus_information_panel_provider_class_init (NautilusInformationPanelProvider
 {
 }
 
-
 void
 nautilus_information_panel_register (void)
 {
